pub struct Hooks { /* private fields */ }Expand description
This is a collection of hooks to component manager events.
Implementations
Sourceimpl Hooks
impl Hooks
pub fn new() -> Self
Sourcepub fn install(&self, hooks: Vec<HooksRegistration>)
pub fn install(&self, hooks: Vec<HooksRegistration>)
For every hook in hooks, add it to the list of hooks that are executed when dispatch
is called for hook.event.
Sourcepub fn install_front_for_test(&self, hooks: Vec<HooksRegistration>)
pub fn install_front_for_test(&self, hooks: Vec<HooksRegistration>)
Same as install, but adds the hook to the front of the queue.
This is test-only because in general it shouldn’t matter what order hooks are executed in. This is useful for tests that need guarantees about hook execution order.
pub async fn dispatch(&self, event: &Event)